@@ -122,7 +122,8 @@ sub add ($m, $row) {
   $row->{tstamp} = time - 1;
   $row->{start} //= $row->{tstamp};
   my $title = {};
-  @$title{qw(title language body)} = delete @$row{qw(title language body)};
+  @$title{qw(title language body data_format)}
+    = delete @$row{qw(title language body data_format)};
   @$title{
     qw(sorting data_type created_at user_id
       group_id changed_by alias permissions published)
@@ -169,10 +170,12 @@ sub save ($m, $id, $row) {
 
   # Get the values for celini
   @$title{
-    qw(page_id title body language id alias changed_by permissions published)}
+    qw(page_id title body language id data_format
+      alias changed_by permissions published)
+    }
     = (
        $id,
-       delete @$row{qw(title body language title_id)},
+       delete @$row{qw(title body language title_id data_format)},
        @$row{qw(alias changed_by permissions published)}
       );
   my $db = $m->dbx->db;
