@@ -48,11 +48,17 @@ if ($DEV_MODE) {
     no warnings 'redefine';
     local *Data::Dumper::qquote = sub {qq["${\(shift)}"]};
     local $Data::Dumper::Useperl = 1;
-    my ($package, $filename, $line, $subroutine) = caller(0);
+    my ($package, $filename, $line) = caller(1);
     state $log = $c->app->log;
     for my $pp (@params) {
-      $log->debug(ref $pp ? $c->dumper($pp) : $pp,
-                  ($pp eq $params[-1] ? "    at $filename:$line" : ''));
+      $log->debug(
+                  ref $pp ? Mojo::Util::dumper($pp) : $pp,
+                  (
+                   $pp eq $params[-1]
+                   ? " at $filename:$line in " . (caller(2))[3]
+                   : ''
+                  )
+                 );
     }
     return;
   }
