@@ -1,9 +1,10 @@
 package Slovo::Validator;
-use Mojo::Base 'Mojolicious::Validator';
+use Mojo::Base 'Mojolicious::Validator', -signatures;
 use feature qw(lexical_subs unicode_strings);
 ## no critic qw(TestingAndDebugging::ProhibitNoWarnings)
 no warnings "experimental::lexical_subs";
-
+use Mojo::ByteStream 'b';
+use Mojo::File 'path';
 has filters => sub {
   +{
     %{$_[0]->SUPER::filters},
@@ -12,6 +13,7 @@ has filters => sub {
    };
 };
 
+
 1;
 
 =encoding utf8
@@ -25,6 +27,12 @@ Slovo::Validator - additional validator filters
 
 Slovo::Validator inherits all filters from Mojo::Validator and implements the following new ones.
 
+=head2 slugify
+
+  $v->required('alias', 'slugify')->size(0, 255);
+
+Generate URL slug for bytestream with L<Mojo::Util/"slugify">.
+
 =head2 xml_escape
 
   $c->validation->optional(title => xml_escape => 'trim')->size(10, 255);
